PRO read_ion_bal, filename

common ionbal_c, ionbal

if (n_elements(filename) eq 0) then $
;  filename = '/data/aped/pse/aped/fitsfiles/RS93_ionbal.fits'
  filename = '/net/notung/usr/people/nitta/APEC/APED/ionbal/AR86_ionbal.fits'
print,filename
ext = 1
fxbopen, unit, filename, ext, header

Nrow = fxpar(header, 'NAXIS2')
if (Nrow eq 0) then begin
    print,'No data in extension.'
    return
endif

fxbread, unit, Temperature,'Temperature'
fxbread, unit, Density,    'Density'
fxbread, unit, Z_Element,  'Z_ELEMENT'
fxbread, unit, X_IONPOP,   'X_IONPOP'

if (size(z_element,/n_dimensions) eq 1) then begin
    N_Z = 1
endif else begin
    N_Z = n_elements(reform(Z_Element(*,0)))
endelse

ionbal = replicate({IonBal_S}, Nrow)
ionbal.Temperature = Temperature
ionbal.Density = Density
if (size(z_element,/n_dimensions) eq 1) then begin
    for i=0,Nrow-1 do begin
        ionbal(i).Z(0) = Z_Element(i)
        for j=1,N_Z-1 do begin
            ionbal(i).indx(j)=ionbal(i).indx(j-1) + Z_Element(i) + 1
        endfor
    endfor
endif else begin
    for i=0,Nrow-1 do begin
        ionbal(i).Z = Z_Element(*,i)
        for j=1,N_Z-1 do begin
            ionbal(i).indx(j)=ionbal(i).indx(j-1) + Z_Element(j-1,i) + 1
        endfor
    endfor
endelse
for i=0,Nrow-1 do ionbal(i).X = X_IONPOP(*,i)
ionbal.filename = filename

fxbclose, unit

return
end

FUNCTION calc_ion_bal, Z, rmJ, T, FILENAME=filename

common ionbal_c, ionbal
;
;  First check inputs
;
if (n_params() lt 3) then begin
    print,'Call as:'
    print,'calc_ion_bal(Z, rmJ, T)'
    print,'where Z is the element number, rmJ the ionization stage in'
    print,'astronomical notation (ie, O VII is Z=8, rmJ=7) and T is the'
    print,'temperature in Kelvin, and can be either a single value or a'
    print,'vector.'
return,-1
endif

if ((n_elements(Z) ne 1)or(n_elements(rmJ) ne 1)) then begin
    print,'Can only calculate results for a SINGLE Z, rmJ'
    return,-2
endif
if ((Z lt 1)or(rmJ lt 1)) then begin
    print,'Illegal Z=',Z,' or rmJ=',rmJ,' value'
    return,-3
endif

if (n_elements(filename) ne 0) then read_ion_bal, filename
if (n_elements(ionbal) eq 0) then read_ion_bal

if (n_elements(ionbal) eq 0) then begin
    print,'Cannot load ionization balance.'
    return,-4
endif
;
;  First figure out if Z, rmJ is even IN this ionization balance calculation
;
gp = where(Z eq ionbal(0).Z,c)
if ((c ne 1)and (rmJ le Z+1)) then begin
    print,strcompress('Ion '+roman_element(Z,rmJ)+$
                      ' is not in the ionization balance.')
    return,-5
endif
;
;  OK, so now extract the appropriate vectors
;
pos = ionbal.indx(gp) + rmJ - 1
pos = pos(0)
ionvec = reform(ionbal.X(pos))
Tvec = ionbal.Temperature
gp = where((T ge min(Tvec))and(T le max(Tvec)),c1)
bp = where((T lt min(Tvec))or (T gt max(Tvec)),c2)
if (c1 eq 0) then begin
    print,'No temperature values inside legal range.'
    return,-6
endif
result = 0.*T 
result(gp) = 10^interpol(alog10(ionvec), alog10(Tvec), alog10(T(gp)))

return, result
end
