FUNCTION expand_E_grid, Emin, Emax, N_E, EVals, EpsVals, SORT=dosort,$
                      SILENT=silent
;
;  Emin    : Minimum energy (keV) for integration (scalar)
;  Emax    : Maximum energy (keV) for integration (scalar)
;  N_E     : Number of points in energy grid.
;  EVals   : Energy points (keV)
;  EpsVals : Spectral values, in photons cm^3 / s / keV
;
if (n_elements(dosort) ne 0) then begin
    print,'Not ready yet'
    stop
endif

if ((Emin ge EVals(N_E-1)) or (Emax le EVals(0))) then begin
    if (n_elements(silent) eq 0) then print,'Spectral values outside range.'
    return,0.
endif
;
;  Check limits & reset if necessary
;
E0 = Emin
E1 = Emax
if (E0 lt EVals(0)) then begin
    if (n_elements(silent) eq 0) then print,'Resetting minimum value.'
    E0 = EVals(0)
endif
if (E1 gt EVals(N_E-1)) then begin
    if (n_elements(silent) eq 0) then print,'Resetting maximum value.'
    E1 = EVals(N_E-1)
endif
;
;  OK, at this point E0 and E1 are within the limits of the EVals.  Now
;  we need to do a simple integration
;
iLow = max(where(Evals(0:N_E-1) le E0))
iHigh= min(where(Evals(0:N_E-1) ge E1))
indx = iLow + indgen(iHigh-iLow+1)
c = n_elements(indx)

Epts =    EVals(indx)
specpts = EpsVals(indx)
slope0 = ((specpts(1)-specpts(0))/(Epts(1)-Epts(0)))
if (c eq 2) then begin
    slope1 = slope0
endif else begin
    slope1 = ((specpts(c-1)-specpts(c-2))/(Epts(c-1)-Epts(c-2)))
endelse
S0   = slope0*(E0-Epts(0))   + specpts(0)
S1 = slope1*(E1-Epts(c-2)) + specpts(c-2)
Epts(0) = E0
Epts(c-1) = E1
specpts(0) = S0
specpts(c-1) = S1
S = 0.0
for iP = 0,c-2 do S = S + 0.5*(Epts(iP+1)-Epts(iP))*(specpts(iP+1)+specpts(iP))

return, S
end
