FUNCTION extract_line, line, Z, rmJ, ll, lu, T, ACTUAL_T=Actual_T, $
                       LAMBDA=lambda, DENSITY=density
;
;  Reads the linelist from a fits file.
;
if (n_params() lt 6) then begin
    print,'Call as:'
    print,'epsilon = extract_line(linelist, Z, rmJ, ll, lu, T,/ACTUAL_T)'
    print,'linelist is an array of structures.'
    print,'/ACTUAL_T is optional; if it is set, then the returned epsilons'
    print,'are only for the values of T found in the line list, and T is'
    print,'set to the matching temperatures.  If /ACTUAL_T is not set, the'
    print,'epsilon values returned match the temperatures set by T.'
    return,-1
end

ll_var = {line_S, lambda: 1., epsilon:1., element:1, ion:1, temperature:1.,$
          density:1., ul:1, ll:1}

gp = where((line.element eq Z)and(line.ion eq rmJ)and(line.ll eq ll)and $
           (line.ul eq lu),count)
if (count eq 0) then begin
    print,'No such transition in linelist'
    return,-2
endif

lambda = line(gp(0)).lambda

if (count eq 1) then begin
    print,'Only one value available'
    T = line(gp).temperature
    density = line(gp).density
    result = line(gp).epsilon
    return, result
endif

if (n_elements(Actual_T) ne 0) then begin
    T = line(gp).temperature
    density = line(gp).density
    return, line(gp).epsilon
endif else begin
    Tvec = line(gp).temperature
    Evec = line(gp).epsilon
    gp1 = where((T ge min(Tvec))and (T le max(Tvec)),c1)
    bp1 = where((T lt min(Tvec))or  (T gt max(Tvec)),c2)
    if (c1 eq 0) then begin
        print,'No T values match the available range.'
        return,-3
    endif
    result = 0*T
    result(gp1) = 10^interpol(alog10(Evec),alog10(Tvec),alog10(T(gp1)))
    return, result
endelse

return,-4
end
