PRO read_continuum, filename, continuum, T_vec, N_vec, lambda_vec, EMIS=emis
;
;  Reads the continuum data from a fits file
;
if (n_params() lt 2) then begin
    print,'Call as:'
    print,'read_continuum, filename, continuum, temperature, density, emission'
    print,'or:'
    print,'read_continuum, filename, continuum'
    print,'continuum is an array of structures; use help, /str, continuum'
    print,'to view the data'
    return
end

done = 0
ext = 1
c_var = {cont_S, Ebin_high: 1., Line:1., Line_Err:1., Pseudo:1.,$
         Pseudo_Err:1., Brems:1., Brems_Err:1., Two_Photon:1.,$
         TwPh_Err:1., Rad_Rec:1., Rad_Rec_Err:1.,temperature:1.,$
         density:1.}

while (not(done)) do begin
    data = mrdfits(filename,ext,header)
    if (n_tags(data) ne 0) then begin
        lambda_val = interp_header(header, 'TOT_EMIS')
        T_val = interp_header(header,'TEMPERAT')
        N_val = interp_header(header,'DENSITY')
        tot_line_val = interp_header(header, 'TOT_LINE',/SILENT)
        tot_brems_val = interp_header(header, 'TOT_BREM',/SILENT)
        tot_rrc_val = interp_header(header, 'TOT_RRC',/SILENT)
        tot_twoph_val = interp_header(header, 'TOT_TWOP',/SILENT)
        Nbin  = interp_header(header,'N_BIN',/INT_RESULT)
        if (ext eq 1) then begin
            T_vec = T_val
            N_vec = N_val
            lambda_vec = lambda_val
            tot_line_vec = tot_line_val
            tot_brems_vec = tot_line_val
            tot_rrc_vec = tot_line_val
            tot_twoph_vec = tot_line_val
            continuum = replicate({cont_S},Nbin(0))
            continuum.Ebin_high = data.Ebin_high
            continuum.Line = data.Line
            continuum.Line_Err = data.Line_Err
            continuum.Pseudo = data.Pseudo
            continuum.Pseudo_Err = data.Pseudo_Err
            continuum.Brems = data.Brems
            continuum.Brems_Err = data.Brems_Err
            continuum.Two_Photon = data.Two_Photon
            continuum.TwPh_Err = data.TwPh_Err
            continuum.Rad_Rec = data.Rad_Rec
            continuum.Rad_Rec_Err = data.Rad_Rec_Err
            continuum.temperature = T_val(0)*(1.+fltarr(Nbin(0)))
            continuum.density = N_val(0)*(1.+fltarr(Nbin(0)))    
        endif else begin
            T_vec = [T_vec,T_val]
            N_vec = [N_vec,N_val]
            lambda_vec = [lambda_vec,lambda_val]
            tot_line_vec  = [tot_line_vec,tot_line_val]
            tot_brems_vec = [tot_brems_vec,tot_brems_val]
            tot_rrc_vec   = [tot_rrc_vec,tot_rrc_val]
            tot_twoph_vec = [tot_twoph_vec,tot_twoph_val]
            cont_tmp = replicate({cont_S},Nbin(0))
            cont_tmp.Ebin_high = data.Ebin_high                   
            cont_tmp.Line = data.Line                             
            cont_tmp.Line_Err = data.Line_Err                     
            cont_tmp.Pseudo = data.Pseudo                         
            cont_tmp.Pseudo_Err = data.Pseudo_Err                 
            cont_tmp.Brems = data.Brems                           
            cont_tmp.Brems_Err = data.Brems_Err                   
            cont_tmp.Two_Photon = data.Two_Photon                 
            cont_tmp.TwPh_Err = data.TwPh_Err                   
            cont_tmp.Rad_Rec = data.Rad_Rec                       
            cont_tmp.Rad_Rec_Err = data.Rad_Rec_Err                 
            cont_tmp.temperature = T_val(0)*(1.+fltarr(Nbin(0)))
            cont_tmp.density = N_val(0)*(1.+fltarr(Nbin(0)))
            continuum = [[continuum],[cont_tmp]]
        endelse
        
        ext = ext + 1
    endif else begin
        done = 1
    endelse
endwhile

;continuum = transpose(continuum)
emis = replicate({Emission_S},ext-1)
emis.T = T_vec
emis.N = N_vec
emis.L_Tot  = Lambda_vec
emis.L_Line = Tot_Line_vec
emis.L_Brems= Tot_Brems_vec
emis.L_RRC  = Tot_RRC_vec
emis.L_Twoph= Tot_Twoph_vec

return
end


